@@ -26,15 +26,13 @@ options:
         to work
 """
 import os
-import urllib.request
 from docopt import docopt
 from cloud_builder.version import __version__
 from cloud_builder.exceptions import exception_handler
+from cloud_builder.defaults import Defaults
 from kiwi.privileges import Privileges
 from kiwi.command import Command
-from cloud_builder.logger import CBLogger
-
-log = CBLogger.get_logger()
+from cloud_builder.cloud_logger import CBCloudLogger
 
 
 @exception_handler
@@ -47,12 +45,18 @@ def main() -> None:
 
     Privileges.check_for_root_permissions()
 
-    # There might be other opportunities to get the IP
-    # when running in the cloud
-    external_ip = urllib.request.urlopen(
-        'https://api.ipify.org'
-    ).read().decode()
+    package_name = args.get('--root').replace(
+        Defaults.get_runner_package_root(), ''
+    ).split('@')[0]
 
+    log = CBCloudLogger('CBRun', package_name)
+
+    build_log_file = os.path.join(
+        args['--root'], '.build.log'
+    )
+    log.info(
+        f'Starting package build. For details see: {build_log_file}'
+    )
     build_run = [
         'chroot', args['--root'], 'bash', '/run.sh'
     ]
@@ -60,13 +64,13 @@ def main() -> None:
         ' '.join(build_run)
     )
     exit_code = return_value >> 8
-    build_log_file = ''
+    status_flags = Defaults.get_status_flags()
     packages = []
 
     if exit_code != 0:
-        log.error('Build Failed')
+        status = status_flags.package_build_failed
     else:
-        build_log_file = os.path.join(args['--root'], '.build.log')
+        status = status_flags.package_build_succeeded
         find_call = Command.run(
             [
                 'find', os.path.join(args['--root'], 'home', 'abuild'),
@@ -76,8 +80,14 @@ def main() -> None:
         if find_call.output:
             packages = find_call.output.strip().split(os.linesep)
 
-    # TODO: send this information to kafka(cb-response)
-    log.info(external_ip)
-    log.info(build_log_file)
-    log.info(packages)
-    log.info(exit_code)
+    log.response(
+        {
+            'identity': log.get_id(),
+            'message': 'Package build finished',
+            'status': status,
+            'package': package_name,
+            'buildlog': build_log_file,
+            'results': packages,
+            'exitcode': exit_code
+        }
+    )
