@@ -19,10 +19,9 @@ import sys
 from functools import wraps
 from typing import Callable
 from cloud_builder.logger import CBLogger
+from cloud_builder.defaults import Defaults
 from kiwi.exceptions import KiwiError
 
-log = CBLogger.get_logger()
-
 
 def exception_handler(func: Callable) -> Callable:
     """
@@ -38,6 +37,9 @@ def exception_handler(func: Callable) -> Callable:
     """
     @wraps(func)
     def wrapper(*args, **kwargs):
+        log = CBLogger.get_logger(
+            logfile=Defaults.get_cb_logfile()
+        )
         try:
             return func(*args, **kwargs)
         except CBError as issue:
