@@ -15,29 +15,20 @@
 # You should have received a copy of the GNU General Public License
 # along with Cloud Builder.  If not, see <http://www.gnu.org/licenses/>
 #
-from cerberus import Validator
-from typing import (
-    List, NamedTuple
-)
 import yaml
+from cerberus import Validator
+from typing import List
 from kafka import KafkaConsumer
 from kafka import KafkaProducer
-from cloud_builder.request import CBRequest
-from cloud_builder.request_schema import request_schema
-from cloud_builder.logger import CBLogger
+from cloud_builder.package_request import CBPackageRequest
+from cloud_builder.package_request_schema import package_request_schema
+from cloud_builder.cloud_logger import CBCloudLogger
 from cloud_builder.exceptions import (
     CBConfigFileNotFoundError,
     CBKafkaProducerException,
     CBKafkaConsumerException
 )
 
-kafka_read_type = NamedTuple(
-    'kafka_read_type', [
-        ('consumer', KafkaConsumer),
-        ('message_list', List)
-    ]
-)
-
 
 class CBKafka:
     """
@@ -56,55 +47,62 @@ class CBKafka:
             .. code:: yaml
 
                 host: kafka-example.com:12345
-                topic: cb-request
         """
         try:
             with open(config_file, 'r') as config:
                 self.kafka_config = yaml.safe_load(config)
         except Exception as issue:
             raise CBConfigFileNotFoundError(issue)
+        self.log = CBCloudLogger('CBKafka', '(system)')
         self.kafka_host = self.kafka_config['host']
-        self.kafka_topic = self.kafka_config['topic']
+        self.consumer: KafkaConsumer = None
+        self.producer: KafkaProducer = None
 
-    def send_request(self, request: CBRequest) -> None:
+    def send_request(self, request: CBPackageRequest) -> None:
         """
-        Send a message conforming to the request_schema to kafka
+        Send a message conforming to the package_request_schema to kafka
         The information for the message is taken from an instance
-        of CBRequest
+        of CBPackageRequest
 
-        :param CBRequest request: Instance of CBRequest
+        :param CBPackageRequest request: Instance of CBPackageRequest
         """
-        message_broker = self.__create_broker()
-        message_broker.send(
-            self.kafka_topic, yaml.dump(request.get_data()).encode()
-        )
+        self._create_producer()
+        message = yaml.dump(request.get_data()).encode()
+        self.producer.send(
+            'cb-request', message
+        ).add_callback(self._on_send_success).add_errback(self._on_send_error)
         # We want this message to go out now
-        message_broker.flush()
+        self.producer.flush()
 
-    def read_request(self, timeout_ms=1000) -> kafka_read_type:
+    def read_request(
+        self, client: str = 'cb-client', group: str = 'cb-group',
+        timeout_ms: int = 1000
+    ) -> List:
         """
         Read messages from kafka. The message has to be valid
-        YAML and has to follow the request_schema in order to
+        YAML and has to follow the package_request_schema in order to
         be processed in the context of the Cloud Builder project
 
+        :param str client: kafka consumer client name
+        :param str group: kafka consumer group name
         :param int timeout_ms: read timeout in ms
 
         :return: list of dicts from yaml.safe_load
 
+        :return: list of yaml dicts validated against package_request_schema
+
         :rtype: list
         """
         request_list = []
-        log = CBLogger.get_logger()
-        kafka = self.read(timeout_ms)
-        for message in kafka.message_list:
+        for message in self.read('cb-request', client, group, timeout_ms):
             try:
                 message_as_yaml = yaml.safe_load(message.value)
-                validator = Validator(request_schema)
+                validator = Validator(package_request_schema)
                 validator.validate(
-                    message_as_yaml, request_schema
+                    message_as_yaml, package_request_schema
                 )
                 if validator.errors:
-                    log.error(
+                    self.log.error(
                         'Validation for "{0}" failed with: {1}'.format(
                             message_as_yaml, validator.errors
                         )
@@ -112,55 +110,72 @@ class CBKafka:
                 else:
                     request_list.append(message_as_yaml)
             except yaml.YAMLError as issue:
-                log.error(
-                    f'YAML load for {message!r} failed with: {issue!r}'
+                self.log.error(
+                    'YAML load for "{0}" failed with: "{1}"'.format(
+                        message, issue
+                    )
                 )
-        return kafka_read_type(
-            consumer=kafka.consumer,
-            message_list=request_list
-        )
+        return request_list
 
-    def acknowledge(self, consumer: KafkaConsumer) -> None:
+    def acknowledge(self) -> None:
         """
         Acknowledge message so we don't get it again for
         this client/group
-
-        :param KafkaConsumer consumer: Kafka Consumer object
         """
-        consumer.commit()
+        if self.consumer:
+            self.consumer.commit()
 
-    def read(self, timeout_ms=1000) -> kafka_read_type:
+    def close(self) -> None:
+        """
+        Close consumer for this client/group
+        """
+        if self.consumer:
+            self.consumer.close()
+
+    def read(
+        self, topic: str, client: str, group: str, timeout_ms: int
+    ) -> List:
         """
         Read messages from kafka.
 
+        :param str topic: kafka topic
+        :param str client: kafka consumer client name
+        :param str group: kafka consumer group name
         :param int timeout_ms: read timeout in ms
 
-        :return: kafka_read_type
+        :return: list of Kafka poll results
 
-        :rtype: Tuple
+        :rtype: List
         """
         message_data = []
-        message_consumer = self.__create_consumer()
+        self._create_consumer(topic, client, group)
         # Call poll twice. First call will just assign partitions
         # for the consumer without content.
         for _ in range(2):
-            raw_messages = message_consumer.poll(timeout_ms=timeout_ms)
+            raw_messages = self.consumer.poll(timeout_ms=timeout_ms)
             for topic_partition, message_list in raw_messages.items():
                 for message in message_list:
                     message_data.append(message)
-        return kafka_read_type(
-            consumer=message_consumer,
-            message_list=message_data
+        return message_data
+
+    def _on_send_success(self, record_metadata):
+        self.log.info(
+            f'Message successfully sent to: {record_metadata.topic}'
         )
 
-    def __create_broker(self) -> KafkaProducer:
+    def _on_send_error(self, exception):
+        self.log.error(
+            f'Message failed with: {exception}'
+        )
+
+    def _create_producer(self) -> KafkaProducer:
         """
         Create a KafkaProducer
 
         :rtype: KafkaProducer
         """
         try:
-            return KafkaProducer(
+            self.producer = KafkaProducer(
                 bootstrap_servers=self.kafka_host
             )
         except Exception as issue:
@@ -168,17 +183,21 @@ class CBKafka:
                 f'Creating kafka producer failed with: {issue!r}'
             )
 
-    def __create_consumer(
-        self, client='cb-client', group='cb-group'
+    def _create_consumer(
+        self, topic: str, client: str, group: str
     ) -> KafkaConsumer:
         """
         Create a KafkaConsumer
 
+        :param str topic: kafka topic
+        :param str client: kafka consumer client name
+        :param str group: kafka consumer group name
+
         :rtype: KafkaConsumer
         """
         try:
-            return KafkaConsumer(
-                self.kafka_topic,
+            self.consumer = KafkaConsumer(
+                topic,
                 auto_offset_reset='earliest',
                 bootstrap_servers=self.kafka_host,
                 client_id=client,
